-- if i'm going to have horrible globals, should at least collect them in one place
TILE_SIZE = 32
USE_NEAREST_NEIGHBOR_SCALING = true
GLOBAL_SCALE = 2

GRAVITY = 13
JUMP_STRENGTH = 450
DIVE_STRENGTH = 900
RUN_ACCEL = 100
RUN_DECEL = 150

MIN_SPEED = 100
MAX_SPEED = 300

SETTLEMENT_WIDTH = 2000
SETTLEMENT_SPACING_BASE = 1500
SETTLEMENT_SPACING_INCREASE = 1000
SETTLEMENT_TORCH_COUNT = 10
SETTLEMENT_TORCH_SCORE = 100
SETTLEMENT_SAFE_GAP = 150

PLAY_MUSIC = true
ENABLE_SOUND = true
currentlyPlaying = nil -- currently playing music

-- thank you love2d wiki
function checkCollision(x1,y1,w1,h1, x2,y2,w2,h2)
  return x1 < x2+w2 and
         x2 < x1+w1 and
         y1 < y2+h2 and
         y2 < y1+h1
end

function checkEntityCollision(ent1, ent2)
    return checkCollision(ent1.x - ent1.width/2, ent1.y - ent1.height/2, ent1.width, ent1.height,
        ent2.x - ent2.width/2, ent2.y - ent2.height/2, ent2.width, ent2.height)
end

-- PITCH SHIFT RANGE is an integer in any value
-- where 0 = no change, 1 = +/-1 octave, 2 = +/-2 octave, etc.
function playSound(sound, pitchShiftRange, sourceLocation)
    if ENABLE_SOUND then
        if pitchShiftRange then
            pitchShiftRange = math.abs(pitchShiftRange)
            local octaveShift = pitchShiftRange * (love.math.random() - 0.5) * 2
            local pitchModifier = math.pow(2, octaveShift)
            sound:setPitch(pitchModifier)
        end
        if sourceLocation then            
            --sound:setPosition(sourceLocation.x/10, sourceLocation.y/10, 0)
        end        
        sound:stop()
        sound:play()
    end    
end

function playMusic(music)
    if ENABLE_SOUND and PLAY_MUSIC then
        if currentlyPlaying ~= music then
            if currentlyPlaying then
                currentlyPlaying:stop()
            end
            music:setLooping(true)
            music:play()
            currentlyPlaying = music
        end
    end    
end

function toggleSound()
    ENABLE_SOUND = not ENABLE_SOUND
    if ENABLE_SOUND then
        if PLAY_MUSIC and currentlyPlaying then
            currentlyPlaying:play()
        end        
    else
        love.audio.stop()
    end    
end


function toggleMusic()
    PLAY_MUSIC = not PLAY_MUSIC
    if currentlyPlaying then        
        if PLAY_MUSIC then
            currentlyPlaying:play()
        else
            currentlyPlaying:stop()
        end
    end
end
