-- Status bar!
-- This was stolen from a different project at the eleventh hour. Forgive me.
local StatusBar = {}
local StatusBarConstructor = {}
local mt = {__index = StatusBar}

local statusBarHeight = 50
local statusBarChangeRate = 1
local margin = 2
local fallbackFont = love.graphics.newFont(20)

function StatusBarConstructor.new(o)
    o = o or {}
    setmetatable(o, mt)
    o.status = o.status or 10
    o.statusMax = o.status or 10
    o.oldStatus = o.status
    o.name = o.name or "Unnamed"
    o.font = o.font or fallbackFont
    o.x = o.x or 0
    o.y = o.y or 0
    o.color = o.color or {255, 255, 255}
    o.width = o.width or love.graphics.getWidth()/3
    o.height = o.height or statusBarHeight
    return o
end

function StatusBar:update(dt, value)
    self.status = value
    self.oldStatus = self.oldStatus + (value - self.oldStatus) * statusBarChangeRate * dt
end

function StatusBar:draw()
    local newValue = self.status
    local valueMax = self.statusMax
    local x = self.x -- margin + self.anchor[1] * (love.graphics.getWidth() - self.width - margin * 2)
    local y = self.y -- margin + self.anchor[2] * (love.graphics.getHeight() - self.height - margin * 2)
    local ratio = newValue / valueMax
    local oldRatio = self.oldStatus / valueMax

    local roundingRadius = 5
    local oldValueRR = math.min(roundingRadius, self.width * oldRatio)
    local newValueRR = math.min(roundingRadius, self.width * ratio)
    -- border
    love.graphics.setColor(self.color[1]/3, self.color[2]/3, self.color[3]/3)
    love.graphics.rectangle("fill", x - margin / 2, y - margin / 2, self.width + margin, self.height + margin, roundingRadius, roundingRadius)
    -- old value
    love.graphics.setColor(self.color[1]/2, self.color[2]/2, self.color[3]/2)
    love.graphics.rectangle("fill", x, y, self.width * oldRatio, self.height, oldValueRR, oldValueRR)
    -- current value
    love.graphics.setColor(self.color)
    love.graphics.rectangle("fill", x, y, self.width * ratio, self.height, newValueRR, newValueRR)
    -- label
    love.graphics.setFont(self.font)
    local textWidth = self.font:getWidth(self.name)
    local textHeight = self.font:getHeight()
    love.graphics.setColor(self.color[1]/3, self.color[2]/3, self.color[3]/3)
    love.graphics.print(self.name, x + self.width / 2 + 1, y + self.height / 2 + 1, 0, 1, 1, textWidth / 2, textHeight / 2)    
    love.graphics.setColor(255, 255, 255)
    love.graphics.print(self.name, x + self.width / 2, y + self.height / 2, 0, 1, 1, textWidth / 2, textHeight / 2)
end



return StatusBarConstructor