local inspect = require 'lib.inspect'
local AssetManager = require 'assets'

local states = {
    PlayState = require 'state.play-state',
    MenuState = require 'state.menu-state',
    CreditsState = require 'state.credits-state'
}

local assetManager = nil
local currentState = nil

function changeState(stateName)
    local stateConstructor = states[stateName]
    if stateConstructor then
        currentState = stateConstructor.new()
        if currentState.init then
            currentState:init(assetManager)
        end
    end
end

function love.load()
    if arg[#arg] == "-debug" then require("mobdebug").start() end

    love.graphics.setDefaultFilter("nearest", "nearest")
    assetManager = AssetManager.new()
    assetManager:loadAllAssets()
    changeState("MenuState")
end

function love.update(dt)
    if currentState then
        currentState:update(dt)
    end
end

function love.draw()
    if currentState then
        currentState:draw()
    end
end

function love.keypressed(key, scancode, isrepeat)
    if currentState then
        currentState:keypressed(key, scancode, isrepeat)
    end
end

function love.keyreleased(key)
    if currentState then
        currentState:keyreleased(key)
    end
end

function love.mousemoved( x, y, dx, dy )
    if currentState then
        currentState:mousemoved(x, y, dx, dy)
    end    
end

function love.mousepressed( x, y, button, istouch )
    if currentState then
        currentState:mousepressed(x, y, button, istouch)
    end
end

function love.resize(w, h)
    if currentState then
        currentState:resize(w, h)
    end
end

function love.joystickadded( joystick )
    if joystick:isGamepad() then
        -- only set for the first known connected gamepad
        firstJoystick = firstJoystick or joystick
    end    
end

function love.joystickremoved( joystick )
    if firstJoystick == joystick then
        firstJoystick = nil
    end    
end

function love.gamepadaxis( joystick, axis, value )
    if joystick == firstJoystick then
        if currentState then
            currentState:gamepadaxis( joystick, axis, value )
        end
    end   
end

function love.gamepadpressed( joystick, button )
    if joystick == firstJoystick then
        if currentState then
            currentState:gamepadpressed(joystick, button)
        end
    end   
end

function love.gamepadreleased( joystick, button )
    if joystick == firstJoystick then
        if currentState then
            currentState:gamepadreleased(joystick, button)
        end        
    end   
end

