local ParticleSystemConstructor = require 'particle.particle'

local FireParticles = setmetatable({}, ParticleSystemConstructor.mt)
local FireParticlesConstructor = {}
local mt = {__index=FireParticles}

local colors = {
    {255, 255, 255},    
    {255, 128, 0},
    {255, 0, 0},
    {0, 0, 0}
}

-- lerp is a value from 0 to 1
function getColor(lerp)
    -- first find the two colors we want to fade between
    local traversal = lerp * (#colors-1)
    local colorIndex = math.floor(traversal) + 1
    local colorLerp = traversal - math.floor(traversal)
    local firstColor = colors[colorIndex]
    local secondColor = colors[colorIndex + 1]
    -- fade between these colours
    local rd = secondColor[1] - firstColor[1]
    local gd = secondColor[2] - firstColor[2]
    local bd = secondColor[3] - firstColor[3]
    return {
        r = firstColor[1] + rd * colorLerp,
        g = firstColor[2] + gd * colorLerp,
        b = firstColor[3] + bd * colorLerp
    }
end


function FireParticlesConstructor.new(o)
    o = o or {}
    setmetatable(o, mt)

    o.particles = {}
    o.x = o.x or 0
    o.y = o.y or 0
    o.num = o.num or 500
    o.r = o.r or 3
    o:init(o.num)

    o.spawnTimer = 0
    o.spawnAt = 0.01
    o.alive = true

    return o
end

function FireParticles:init(num)
    local screenWidth = love.graphics.getWidth() / GLOBAL_SCALE
    local screenHeight = love.graphics.getHeight() / GLOBAL_SCALE

    self.particles = {}
    for i=1,num do        
        self.particles[#self.particles+1] = {
            x=self.x + love.math.random(-3, 3),
            y=self.y + love.math.random(-3, 3),
            vx=love.math.random(-10, 10),
            vy=love.math.random(-20, 10),
            radius=self.r,
            alive=false
        }
    end
end

function FireParticles:update(dt, movement)

    if self.alive then
        self.spawnTimer = self.spawnTimer + dt
        if self.spawnTimer > self.spawnAt then
            for i=1,5 do
                local p = self:getFirstDead()
                if p then
                    self:resetParticle(p)
                end            
            end
            self.spawnTimer = 0
        end    
    end

    for _,p in ipairs(self.particles) do
        if p.alive then
            p.x = p.x + p.vx * dt - movement
            p.y = p.y + p.vy * dt 
            p.vy = p.vy - 10 * dt
            p.ttl = p.ttl - dt

            if p.ttl < 0 then
                p.alive = false
            end      
        else
        end
    end    
end

function FireParticles:resetParticle(p)
    local ttl = love.math.random() * 0.6 + 0.1
    p.x=self.x + love.math.random(-3, 3)
    p.y=self.y + love.math.random(-3, 3)
    p.vx=love.math.random(-10, 10)
    p.vy=love.math.random(-20, 10)
    p.ttl=ttl
    p.maxTtl=ttl
    p.alive = true
end


function FireParticles:draw()
    for _,p in ipairs(self.particles) do
        if p.alive then
            local lerp = p.ttl/p.maxTtl
            local color = getColor(1-lerp)
            love.graphics.setColor(color.r, color.g, color.b, lerp * 255)
            love.graphics.ellipse("fill", p.x, p.y, p.radius, p.radius)
        end
    end    
end


return FireParticlesConstructor