local ParticleSystemConstructor = require 'particle.particle'

local SnowParticles = setmetatable({}, ParticleSystemConstructor.mt)
local SnowParticlesConstructor = {}
local mt = {__index=SnowParticles}

function SnowParticlesConstructor.new(o)
    o = o or {}
    setmetatable(o, mt)

    o.particles = {}
    o.scrollFactor = o.scrollFactor or 0 -- 0 = behind things, 1 = in front of things
    o:init(o.scrollFactor, 700)

    return o
end

function SnowParticles:init(scrollFactor, num)
    local screenWidth = love.graphics.getWidth() / GLOBAL_SCALE
    local screenHeight = love.graphics.getHeight() / GLOBAL_SCALE
    
    self.particles = {}
    for i=1,num do
        local shade = 128 + love.math.random(128)
        self.particles[#self.particles+1] = {
            x=love.math.random(screenWidth),
            y=love.math.random(screenHeight),
            scrollFactor=scrollFactor + love.math.random(),
            vx=love.math.random(-30, 30),
            vy=love.math.random(0, 60),
            radius=1,
            alive=true,
            color={r=shade, g=shade, b=shade}
        }
    end
end

function SnowParticles:update(dt, movement)
    local screenWidth = love.graphics.getWidth() / GLOBAL_SCALE
    local screenHeight = love.graphics.getHeight() / GLOBAL_SCALE
    
    for _,p in ipairs(self.particles) do
        p.x = p.x + p.vx * dt - movement * p.scrollFactor
        p.y = p.y + p.vy * dt 
        if p.x < -p.radius then
            p.x = screenWidth + p.radius
        elseif p.x > screenWidth + p.radius then
            p.x = -p.radius
        end
        
        if p.y > screenHeight + p.radius then
            p.y = -p.radius
        end
        
    end    
end

function SnowParticles:draw()
    for _,p in ipairs(self.particles) do
        love.graphics.setColor(p.color.r, p.color.g, p.color.b)
        love.graphics.ellipse("fill", p.x, p.y, p.radius, p.radius)
    end    
end


return SnowParticlesConstructor