require 'globals'
local StateConstructor = require 'state.state'
local SnowParticles = require 'particle.snow'

local CreditsState = setmetatable({}, StateConstructor.mt)
local CreditsStateConstructor = {}
local mt = {__index = CreditsState}

function CreditsStateConstructor.new(o)
    o = o or {}
    setmetatable(o, mt)    
    o.margin = 10
    return o
end

function CreditsState:init(assetManager)
    self.font = assetManager:getFont("aesymatt16")
    
    self.music = assetManager:getMusic("gameTitle")
    playMusic(self.music)   
    
    self.timer = 0
    self.snow = SnowParticles.new()
end

function CreditsState:update(dt)
    self.timer = self.timer + dt
    self.snow:update(dt, 0)
end

function CreditsState:keypressed(key, scancode, isrepeat)
    if key == "c" then
        changeState("MenuState")
    end
    
    if key == "m" then
        toggleSound()
    elseif key == "0" or key == "o" then
        toggleMusic()                
    end
end

function CreditsState:draw()
    love.graphics.scale(GLOBAL_SCALE, GLOBAL_SCALE)
    local screenWidth = love.graphics.getWidth() / GLOBAL_SCALE
    local screenHeight = love.graphics.getHeight() / GLOBAL_SCALE
    
    love.graphics.setColor(54, 52, 72)
    love.graphics.rectangle("fill", 0, 0, screenWidth, screenHeight)
    
    self.snow:draw()

    local creditsMessage = [[Well, it's been a pretty long time since my last Ludum Dare entry!
Glad to finally be back into the swing of things.

All code, images, sounds, and music, regardless of quality, 
are the creation and fault of Cirrial, 2016.
August 27th thru 28th, what a time.

Shout outs to the SPEEP crowd, my family, 
and all of you wonderful people.
Entrants and players alike, you rock!
Thanks for playing my game!

Hit C to go back to the title screen.]]
    love.graphics.setFont(self.font)
    love.graphics.setColor(0, 0, 0)    
    love.graphics.printf(creditsMessage, 0, 21, screenWidth - 1, "center")
    love.graphics.setColor(255, 255, 255)    
    love.graphics.printf(creditsMessage, 0, 22, screenWidth, "center")
end

return CreditsStateConstructor