require 'globals'
local StateConstructor = require 'state.state'

local MenuState = setmetatable({}, StateConstructor.mt)
local MenuStateConstructor = {}
local mt = {__index = MenuState}

function MenuStateConstructor.new(o)
    o = o or {}
    setmetatable(o, mt)    
    o.margin = 10
    return o
end

function MenuState:init(assetManager)
    self.font = assetManager:getFont("aesymatt16")
    self.titleScreenImage = assetManager:getImage("titleScreen")
    self.titleImage = assetManager:getImage("title")
    
    
    self.music = assetManager:getMusic("gameTitle")
    playMusic(self.music)    
    
    self.titleY = 20
    self.timer = 0
end

function MenuState:update(dt)
    self.timer = self.timer + dt
    
    self.titleY = 20 + math.sin(self.timer * 4) * 5
end

function MenuState:keypressed(key, scancode, isrepeat)
    if key == "space" or key == "enter" then
        changeState("PlayState")
    elseif key == "c" then
        changeState("CreditsState")
    end
    
    if key == "m" then
        toggleSound()
    elseif key == "0" or key == "o" then
        toggleMusic()                
    end
end

function MenuState:draw()
    love.graphics.scale(GLOBAL_SCALE, GLOBAL_SCALE)
    local screenWidth = love.graphics.getWidth() / GLOBAL_SCALE
    local screenHeight = love.graphics.getHeight() / GLOBAL_SCALE
    
    love.graphics.draw(self.titleScreenImage, 0, 0)
    love.graphics.draw(self.titleImage, screenWidth/2 - self.titleImage:getWidth()/2, self.titleY)
    
    local titleMessage = "Bring fire to the freezing settlements!\n\n" ..
        "Jump with X/W/Up/Space and dive with C/S/Down.\n" ..
        "Left/A and Right/D to try speeding up or slowing down.\n" ..
        "Hit M at any time to mute/unmute sounds and music.\n(Use 0 for just the music)\n\n" ..
        "Press Space/Enter to play.\nHit C for credits."
    love.graphics.setFont(self.font)
    love.graphics.setColor(0, 0, 0)    
    love.graphics.printf(titleMessage, 0, screenHeight/2 - 9, screenWidth - 1, "center")
    love.graphics.setColor(255, 255, 255)    
    love.graphics.printf(titleMessage, 0, screenHeight/2 - 10, screenWidth, "center")
end

return MenuStateConstructor