-- Simple timer that keeps track of its elapsed time and automatically calls a callback on hitting a trigger

local TimerConstructor = {}
local Timer = {}
local mt = {__index = Timer}

function TimerConstructor.new (o)
    o = o or {}
    setmetatable(o, mt)
    o.elapsed = o.elapsed or 0
    o.trigger = o.trigger or 0
    o.direction = o.direction or 1
    o.multiplier = o.multiplier or 1
    o.loops = o.loops or false
    o.running = o.running or false
    o.data = o.data or {}
    return o
end

function Timer:update (dt)    
    if self.running then
        self.elapsed = self.elapsed + dt * self.direction * self.multiplier
        if (self.elapsed >= self.trigger and self.direction > 0) or (self.elapsed <= 0 and self.direction < 0) then
            if self.loops then
                self:reset()
            else
                self:stop()
            end

            if self.callback then
                self:callback(self.data)
            end        
        end
    end
end

function Timer:stop (runCallback)
    self.elapsed = self.direction < 0 and 0 or self.trigger
    self.running = false
    if runCallback and self.callback then
        self:callback(self.data)
    end    
end


function Timer:reset (trigger)
    self.trigger = trigger or self.trigger
    self.elapsed = self.direction < 0 and self.trigger or 0
    self.running = true
end

function Timer:progress ()
    if self.direction < 0 then
        return (self.trigger - self.elapsed) / self.trigger
    else
        return self.elapsed / self.trigger
    end
end

return TimerConstructor